# russian_quotes

## Установка
```shell
pip install russian-quotes
```

## Пример использования
```py
from russian_quotes import get_quote

text, author = get_quote()

print(f'Text: {text} Author: {author}')
```

## Зависимости

[Python >=3.10](https://www.python.org/downloads/release/python-310)

## Лицензия

[MIT](http://en.wikipedia.org/wiki/MIT_License)
